==> xnjb-1.1.1.tar.bz2: xnjb-1.1.1/Track.h <==
//
//  Track.h
//  XNJB
//
//  Created by Richard Low on Sun Jul 18 2004.
//

#import <Foundation/Foundation.h>
#import "MyItem.h"

// these should be in numerical order of sorting that we'd like compareByCodec to use
typedef enum _codecTypes {CODEC_UNDEFINED = -1, CODEC_MP3 = 0, CODEC_WMA = 1, CODEC_WAV = 2, CODEC_AA = 3} codecTypes;

@interface Track : MyItem {
@private
  NSString *title;
	NSString *album;
	NSString *artist;
	NSString *genre;
	NSString *filename;
	NSString *fullPath;
	unsigned length;
	unsigned trackNumber;
	unsigned year;
	codecTypes codec;
	unsigned long long filesize;
}
- (id)initWithTrack:(Track *)track;
- (NSString *)title;
- (void)setTitle:(NSString *)newTitle;
- (NSString *)album;
- (void)setAlbum:(NSString *)newAlbum;
- (NSString *)artist;
- (void)setArtist:(NSString *)newArtist;
- (NSString *)genre;
- (void)setGenre:(NSString *)newGenre;
- (NSString *)filename;
- (void)setFilename:(NSString *)newFilename;
- (NSString *)fullPath;
- (void)setFullPath:(NSString *)newFullPath;
- (unsigned)length;
- (NSString *)lengthString;
- (void)setLength:(unsigned)newLength;
- (unsigned)trackNumber;
- (void)setYear:(unsigned)newYear;
- (unsigned)year;
- (void)setTrackNumber:(unsigned)newTrackNumber;
- (codecTypes)codec;
- (NSString *)codecString;
- (NSString *)njbCodec;
- (void)setCodec:(codecTypes)newCodec;
- (unsigned long long)filesize;
- (NSString *)filesizeString;
- (void)setFilesize:(unsigned long long)newFilesize;
- (void)setValuesToTrack:(Track *)track;

- (NSComparisonResult)compareByLength:(Track *)other;
- (NSComparisonResult)compareUnsignedInts:(unsigned)mine withOther:(unsigned)theirs;

@end

==> xnjb-1.5.1.tar.bz2: xnjb-1.5.1/Track.h <==
//
//  Track.h
//  XNJB
//
//  Created by Richard Low on Sun Jul 18 2004.
//

#import <Foundation/Foundation.h>
#import "MyItem.h"

@interface Track : MyItem {
@private
  NSString *title;
	NSString *album;
	NSString *artist;
	NSString *genre;
	NSString *filename;
	NSString *fullPath;
	unsigned length;
	unsigned trackNumber;
	unsigned year;
	unsigned long long filesize;
  NSBitmapImageRep *image;
  NSDate *dateAdded;
  int rating;
}
- (id)initWithTrack:(Track *)track;
- (NSString *)title;
- (void)setTitle:(NSString *)newTitle;
- (NSString *)album;
- (void)setAlbum:(NSString *)newAlbum;
- (NSString *)artist;
- (void)setArtist:(NSString *)newArtist;
- (NSString *)genre;
- (void)setGenre:(NSString *)newGenre;
- (NSString *)filename;
- (void)setFilename:(NSString *)newFilename;
- (NSString *)fullPath;
- (void)setFullPath:(NSString *)newFullPath;
- (unsigned)length;
- (NSString *)lengthString;
- (void)setLength:(unsigned)newLength;
- (unsigned)trackNumber;
- (void)setYear:(unsigned)newYear;
- (unsigned)year;
- (void)setTrackNumber:(unsigned)newTrackNumber;
- (NSString *)njbCodec;
- (unsigned long long)filesize;
- (NSString *)filesizeString;
- (void)setFilesize:(unsigned long long)newFilesize;
- (void)setValuesToTrack:(Track *)track;
- (void)fileTypeFromExtension;
- (void)setImage:(NSBitmapImageRep *)newImage;
- (NSBitmapImageRep *)image;
- (void)setDateAdded:(NSDate *)newDateAdded;
- (NSDate *)dateAdded;
- (void)setRating:(unsigned int)newRating;
- (unsigned int)rating;

- (NSComparisonResult)compareByLength:(Track *)other;
- (NSComparisonResult)compareUnsignedInts:(unsigned)mine withOther:(unsigned)theirs;

@end
